==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebRangeSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueEventArgsDescriptionMetadata } from "./WebRangeSliderValueEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebRangeSliderDescription } from "./WebRangeSliderDescription";
/**
 * @hidden
 */
var WebRangeSliderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRangeSliderDescriptionMetadata, _super);
    function WebRangeSliderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRangeSliderDescriptionMetadata.b = function (a) {
        if (WebRangeSliderDescriptionMetadata.a == null) {
            WebRangeSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRangeSliderDescriptionMetadata.c(WebRangeSliderDescriptionMetadata.a);
        }
        if (a.g(WebRangeSliderDescriptionMetadata.a)) {
            return;
        }
        a.s(WebRangeSliderDescriptionMetadata.a);
        WebRangeSliderValueEventArgsDescriptionMetadata.d(a);
    };
    WebRangeSliderDescriptionMetadata.c = function (a) {
        WebSliderBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RangeSlider");
        a.item("Lower", "Number:double");
        a.item("Upper", "Number:double");
        a.item("AriaLabelLower", "String");
        a.item("AriaLabelUpper", "String");
        a.item("InputRef", "EventRef::input");
        a.item("ChangeRef", "EventRef::change");
    };
    WebRangeSliderDescriptionMetadata.d = function (a) {
        WebRangeSliderDescriptionMetadata.b(a);
        a.u("WebRangeSlider", function () { return new WebRangeSliderDescription(); });
        a.t("WebRangeSlider", WebRangeSliderDescriptionMetadata.a);
    };
    WebRangeSliderDescriptionMetadata.$t = markType(WebRangeSliderDescriptionMetadata, 'WebRangeSliderDescriptionMetadata');
    WebRangeSliderDescriptionMetadata.a = null;
    return WebRangeSliderDescriptionMetadata;
}(Base));
export { WebRangeSliderDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebRangeSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueEventArgsDescriptionMetadata } from "./WebRangeSliderValueEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebRangeSliderDescription } from "./WebRangeSliderDescription";
/**
 * @hidden
 */
var WebRangeSliderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRangeSliderDescriptionMetadata, _super);
    function WebRangeSliderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRangeSliderDescriptionMetadata.b = function (a) {
        if (WebRangeSliderDescriptionMetadata.a == null) {
            WebRangeSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRangeSliderDescriptionMetadata.c(WebRangeSliderDescriptionMetadata.a);
        }
        if (a.j(WebRangeSliderDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRangeSliderDescriptionMetadata.a);
        WebRangeSliderValueEventArgsDescriptionMetadata.d(a);
    };
    WebRangeSliderDescriptionMetadata.c = function (a) {
        WebSliderBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RangeSlider");
        a.item("__tagNameWC", "String:igc-range-slider");
        a.item("Lower", "Number:double");
        a.item("Upper", "Number:double");
        a.item("AriaLabelLower", "String");
        a.item("AriaLabelUpper", "String");
        a.item("InputRef", "EventRef::input");
        a.item("ChangeRef", "EventRef::change");
    };
    WebRangeSliderDescriptionMetadata.d = function (a) {
        WebRangeSliderDescriptionMetadata.b(a);
        a.aa("WebRangeSlider", function () { return new WebRangeSliderDescription(); });
        a.z("WebRangeSlider", WebRangeSliderDescriptionMetadata.a);
    };
    WebRangeSliderDescriptionMetadata.$t = markType(WebRangeSliderDescriptionMetadata, 'WebRangeSliderDescriptionMetadata');
    WebRangeSliderDescriptionMetadata.a = null;
    return WebRangeSliderDescriptionMetadata;
}(Base));
export { WebRangeSliderDescriptionMetadata };
